@@ -179,19 +179,14 @@ int getrusage(int who, struct rusage *rusage);
 #define PATH_SYSLOG     "/private/var/log/system.log"
 #endif
 
-#ifdef NEXTSTEP3
+#ifdef NEXTSTEP
 #define HAVE_GETRUSAGE
 #define SIZEOF_IS_LONG_INT
 /* not supported */
 #define SA_RESTART 0
 #define O_RSYNC 0
-#if defined(NEXTSTEP3_HPPA) || defined(NEXTSTEP4)
 /* replace with corresponding bsd call */
 #define setsid() setpgrp(0, getpid())
-#else /* NEXTSTEP3_HPPA */
-/* select, ftruncate, fchmod */
-#include <libc.h>
-#endif /* NEXTSTEP3_HPPA */
 /* in ansi string.h but undefined in -posix */
 #define bzero(b,len) memset(b,0,len)
 #ifndef FD_CLOEXEC
