@@ -249,14 +249,7 @@ void main_loop(int *service_socket, int numsock, time_t seed_stat_interval,
     }
 
     if (gather_fd != -1) {
-      if (FD_ISSET(gather_fd, &efds)) {
-	if (debug)
-	  (void)fprintf(stderr, "Closing connection to gatherer (efds)\n");
-	(void)close(gather_fd);
-	gather_fd = -1;
-	count_openfd--;
-      }
-      else if (FD_ISSET(gather_fd, &rfds)) {
+      if (FD_ISSET(gather_fd, &rfds)) {
 	/*
 	 * Bytes are coming back from the gatherer process. Read chunks of
 	 * up to 10240 bytes and feed them into the PRNG
@@ -276,6 +269,13 @@ void main_loop(int *service_socket, int numsock, time_t seed_stat_interval,
 	  count_openfd--;
 	}
       }
+      else if (FD_ISSET(gather_fd, &efds)) {
+	if (debug)
+	  (void)fprintf(stderr, "Closing connection to gatherer (efds)\n");
+	(void)close(gather_fd);
+	gather_fd = -1;
+	count_openfd--;
+      }
       if (gather_fd == -1) {
 	/*
 	 * The formerly running gatherer has just been shut down for normal
